@@ -1,55 +1,53 @@
 #' Log Predicate
-#' 
+#'
 #' Log predicate to bridge the previous log with the new
 #' [log::Logger] package.
-#' 
-#' @noRd 
+#'
+#' @noRd
 #' @keywords internal
-logPredicate <- function(log){
+logPredicate <- function(log) {
   function() log
 }
 
 #' Logger
-#' 
+#'
 #' Returns a new logger using the `log` package.
-#' 
+#'
 #' @param prefix String to prefix all log messages.
 #' @param write Whether to write the log to the `file`.
-#' @param file Name of the file to dump the logs to, 
+#' @param file Name of the file to dump the logs to,
 #' only used if `write` is `TRUE`.
-#' @param sep Separator between `prefix` and other 
+#' @param sep Separator between `prefix` and other
 #' flags and messages.
-#' 
-#' @examples 
+#'
+#' @examples
 #' log <- new_log()
 #' log$log("Hello world")
-#' 
+#'
 #' @return An R& of class `log::Logger`.
-#' 
-#' @export 
+#'
+#' @export
 new_log <- function(
-  prefix = ">", 
-  write = FALSE, 
-  file = "ambiorix.log", 
+  prefix = ">",
+  write = FALSE,
+  file = "ambiorix.log",
   sep = ""
-){
+) {
   log::Logger$new(
     prefix = prefix,
     write = write,
     file = file,
     sep = sep
-  )$
-  date()$
-  time()
+  )$date()$time()
 }
 
 #' Customise logs
-#' 
+#'
 #' Customise the internal logs used by Ambiorix.
-#' 
+#'
 #' @param log An object of class `Logger`, see
 #' [log::Logger].
-#' 
+#'
 #' @name set_log
 #' @return The `log` object.
 #' @examples
@@ -57,11 +55,11 @@ new_log <- function(
 #' info_logger <- log::Logger$new("INFO")
 #' success_logger <- log::Logger$new("SUCCESS")
 #' error_logger <- log::Logger$new("ERROR")
-#' 
+#'
 #' info_logger$log("This is an info message.")
 #' success_logger$log("This is a success message.")
 #' error_logger$log("This is an error message.")
-#' 
+#'
 #' # set custom loggers for Ambiorix:
 #' set_log_info(info_logger)
 #' set_log_success(success_logger)
@@ -93,9 +91,9 @@ set_log_error <- function(log) {
 }
 
 #' CLI symbols
-#' 
+#'
 #' CLI Symbols for log
-#' 
+#'
 #' @keywords internal
 #' @noRd
 success <- function() {
