@@ -1,30 +1,31 @@
 WebsocketHandler <- R6::R6Class(
   "WebsocketHandler",
   public = list(
-    initialize = function(name, fun){
+    initialize = function(name, fun) {
       assert_that(not_missing(fun))
       assert_that(not_missing(name))
 
       private$.fun <- fun
       private$.name <- name
     },
-    receive = function(message, ws){
+    receive = function(message, ws) {
       args <- formalArgs(private$.fun)
 
-      if(length(args) > 1) {
+      if (length(args) > 1) {
         ws <- Websocket$new(ws)
         private$.fun(message$message, ws)
       } else {
         private$.fun(message$message)
       }
     },
-    is_handler = function(message){
-      if(is.null(message$isAmbiorix))
+    is_handler = function(message) {
+      if (is.null(message$isAmbiorix)) {
         return(FALSE)
+      }
 
       private$.name == message$name
     },
-    print = function(){
+    print = function() {
       foo <- paste0(deparse(private$.fun), collapse = "\n")
       cli::cli_alert_info("receive: {.code receive(message, ws)}")
       cli::cli_ul("Listening on message:")
@@ -39,71 +40,71 @@ WebsocketHandler <- R6::R6Class(
 )
 
 #' Websocket
-#' 
+#'
 #' Handle websocket messages.
-#' 
+#'
 #' @return A Websocket object.
 #' @examples
 #' # create an Ambiorix app with websocket support:
 #' if (interactive()) {
 #'   library(ambiorix)
-#' 
+#'
 #'   home_get <- function(req, res) {
 #'     res$send("hello, world!")
 #'   }
-#' 
+#'
 #'   greeting_ws_handler <- function(msg, ws) {
 #'     cat("Received message:", "\n")
 #'     print(msg)
 #'     ws$send("greeting", "Hello from the server!")
 #'   }
-#' 
+#'
 #'   app <- Ambiorix$new(port = 8080)
 #'   app$get("/", home_get)
 #'   app$receive("greeting", greeting_ws_handler)
 #'   app$start()
 #' }
-#' 
+#'
 #' # create websocket client from another R session:
 #' if (interactive()) {
 #'   client <- websocket::WebSocket$new("ws://127.0.0.1:8080", autoConnect = FALSE)
-#' 
+#'
 #'   client$onOpen(function(event) {
 #'     cat("Connection opened\n")
-#' 
+#'
 #'     msg <- list(
 #'       isAmbiorix = TRUE, # __MUST__ be set!
 #'       name = "greeting",
 #'       message = "Hello from the client!"
 #'     )
-#' 
+#'
 #'     # serialise:
 #'     msg <- yyjsonr::write_json_str(msg, auto_unbox = TRUE)
-#' 
+#'
 #'     client$send(msg)
 #'   })
-#' 
+#'
 #'   client$onMessage(function(event) {
 #'     cat("Received message from server:", event$data, "\n")
 #'   })
-#' 
+#'
 #'   client$connect()
 #' }
-#' 
-#' @export 
+#'
+#' @export
 Websocket <- R6::R6Class(
   "Websocket",
   public = list(
     #' @details Constructor
-    #' @param ws 
-    initialize = function(ws){
+    #' @param ws The websocket
+    initialize = function(ws) {
       private$.ws <- ws
     },
     #' @details Send a message
     #' @param name Name, identifier, of the message.
     #' @param message Content of the message, anything that can be
     #' serialised to JSON.
-    send = function(name, message){
+    send = function(name, message) {
       message <- list(
         name = name,
         message = message,
@@ -112,7 +113,7 @@ Websocket <- R6::R6Class(
       private$.ws$send(serialise(message))
     },
     #' @details Print
-    print = function(){
+    print = function() {
       cli::cli_li("send: {.code send(name, message)}")
     }
   ),
@@ -122,19 +123,19 @@ Websocket <- R6::R6Class(
 )
 
 #' Websocket Client
-#' 
+#'
 #' Handle ambiorix websocket client.
-#' 
+#'
 #' @param path Path to copy the file to.
-#' 
+#'
 #' @section Functions:
 #' - `copy_websocket_client` Copies the websocket client file, useful when
 #'   ambiorix was not setup with the ambiorix generator.
 #' - `get_websocket_client_path` Retrieves the full path to the local websocket client.
 #' - `get_websocket_clients` Retrieves clients connected to the server.
-#' 
+#'
 #' @name websocket_client
-#' @return 
+#' @return
 #' - `copy_websocket_client`: String. The new path (invisibly).
 #' - `get_websocket_client_path`: String. The path to the local websocket client.
 #' - `get_websocket_clients`: List. Websocket clients.
@@ -147,8 +148,8 @@ Websocket <- R6::R6Class(
 #'     }
 #'   )
 #' }
-#' @export 
-copy_websocket_client <- function(path){
+#' @export
+copy_websocket_client <- function(path) {
   assert_that(not_missing(path))
 
   lib <- get_websocket_client_path()
@@ -156,7 +157,7 @@ copy_websocket_client <- function(path){
 }
 
 #' @rdname websocket_client
-get_websocket_client_path <- function(){
+get_websocket_client_path <- function() {
   system.file("ambiorix.js", package = "ambiorix")
 }
 
