@@ -23,13 +23,18 @@ test_that("Ambiorix", {
 
   expect_error(app$set_404("error"))
   expect_error(app$set_404(function(req) {}))
-  expect_s3_class(app$set_404(function(req, res) {
-    res$send("Errr")
-  }), "Ambiorix")
+  expect_s3_class(
+    app$set_404(function(req, res) {
+      res$send("Errr")
+    }),
+    "Ambiorix"
+  )
 
   expect_error(app$serialiser("error"))
-  expect_s3_class(app$serialiser(function(data) {
-    return("data")
-  }), "Ambiorix")
-
+  expect_s3_class(
+    app$serialiser(function(data) {
+      return("data")
+    }),
+    "Ambiorix"
+  )
 })
